"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.constructShield = exports.wrapWithExport = exports.wrapWithTrpcShieldCall = exports.wrapWithObject = exports.getImports = void 0;
const getImports = (type) => {
    const trpcImportStatement = "import * as trpc from '@trpc/server';\n";
    const trpcShieldImportStatement = "import { shield, allow } from 'trpc-shield';\n";
    return type === 'trpc' ? trpcImportStatement : trpcShieldImportStatement;
};
exports.getImports = getImports;
const wrapWithObject = ({ shieldItemLines, }) => {
    let wrapped = '{';
    wrapped += '\n';
    wrapped += Array.isArray(shieldItemLines)
        ? '  ' + shieldItemLines.join(',\r\n')
        : '  ' + shieldItemLines;
    wrapped += '\n';
    wrapped += '}';
    return wrapped;
};
exports.wrapWithObject = wrapWithObject;
const wrapWithTrpcShieldCall = ({ shieldObjectTextWrapped, }) => {
    let wrapped = 'shield(';
    wrapped += '\n';
    wrapped += '  ' + shieldObjectTextWrapped;
    wrapped += '\n';
    wrapped += ')';
    return wrapped;
};
exports.wrapWithTrpcShieldCall = wrapWithTrpcShieldCall;
const wrapWithExport = ({ shieldObjectText, }) => {
    return `export const permissions = ${shieldObjectText};`;
};
exports.wrapWithExport = wrapWithExport;
const constructShield = ({ queries, mutations, subscriptions, }) => {
    if (queries.length === 0 &&
        mutations.length === 0 &&
        subscriptions.length === 0) {
        return '';
    }
    let rootItems = '';
    if (queries.length > 0) {
        const queryLinesWrapped = `query: ${(0, exports.wrapWithObject)({
            shieldItemLines: queries.map((query) => `${query}: allow`),
        })},`;
        rootItems += queryLinesWrapped;
    }
    if (mutations.length > 0) {
        const mutationLinesWrapped = `mutation: ${(0, exports.wrapWithObject)({
            shieldItemLines: mutations.map((mutation) => `${mutation}: allow`),
        })},`;
        rootItems += mutationLinesWrapped;
    }
    if (subscriptions.length > 0) {
        const subscriptionLinesWrapped = `subscription: ${(0, exports.wrapWithObject)({
            shieldItemLines: subscriptions.map((subscription) => `${subscription}: allow`),
        })},`;
        rootItems += subscriptionLinesWrapped;
    }
    if (rootItems.length === 0)
        return '';
    let shieldText = (0, exports.getImports)('trpc-shield');
    shieldText += '\n\n';
    shieldText += (0, exports.wrapWithExport)({
        shieldObjectText: (0, exports.wrapWithTrpcShieldCall)({
            shieldObjectTextWrapped: (0, exports.wrapWithObject)({ shieldItemLines: rootItems }),
        }),
    });
    return shieldText;
};
exports.constructShield = constructShield;
//# sourceMappingURL=helpers.js.map